@@ -15,7 +15,7 @@ from onnx2kerastl import onnx_to_keras  # type: ignore
 from onnx2kerastl.exceptions import OnnxUnsupported  # type: ignore
 from tensorflow.keras.models import load_model  # type: ignore
 
-from leap_model_parser.contract.importmodelresponse import NodeResponse, ImportModelTypeEnum
+from leap_model_parser.contract.importmodelresponse import DatasetInfo, NodeResponse, ImportModelTypeEnum
 from leap_model_parser.keras_json_model_import import KerasJsonModelImport
 
 onnx_imported = False
@@ -29,9 +29,9 @@ if spec is not None:
 
 class ModelParser:
     def __init__(self, should_transform_inputs_and_outputs=False,
-                 custom_layers: Optional[Dict[str, Type[tf.keras.layers.Layer]]] = None):
+                 custom_layers: Optional[Dict[str, Type[tf.keras.layers.Layer]]] = None, dataset_info: Optional[DatasetInfo] = None):
         self._should_transform_inputs_and_outputs = should_transform_inputs_and_outputs
-
+        self.dataset_info = dataset_info
         self.custom_layers = custom_layers
         if custom_layers is None:
             self.custom_layers = {}
@@ -53,7 +53,7 @@ class ModelParser:
         file_path = str(model_path)
         try:
             model_schema, keras_model = model_to_keras_converter(file_path)
-            model_generator = KerasJsonModelImport(self.custom_layers)
+            model_generator = KerasJsonModelImport(self.custom_layers, self.dataset_info)
             graph = model_generator.generate_graph(model_schema)
             return graph, keras_model
         except Exception as e:
@@ -65,7 +65,7 @@ class ModelParser:
 
                 rebuilt_model = rebuild_model(keras_model)
                 model_schema, keras_model = self.convert_to_keras_model(rebuilt_model)
-                model_generator = KerasJsonModelImport(self.custom_layers)
+                model_generator = KerasJsonModelImport(self.custom_layers, self.dataset_info)
                 graph = model_generator.generate_graph(model_schema)
                 return graph, keras_model
             else:
@@ -104,7 +104,9 @@ class ModelParser:
             raise OnnxUnsupported()
 
         onnx_model = onnx.load_model(file_path)
-        input_names = [_input.name for _input in onnx_model.graph.input]
+        input_all = [_input.name for _input in onnx_model.graph.input]
+        input_initializer = [node.name for node in onnx_model.graph.initializer]
+        input_names = list(set(input_all) - set(input_initializer))
         k_model = onnx_to_keras(onnx_model, input_names=input_names,
                                 name_policy='attach_weights_name')
         return self.convert_to_keras_model(k_model)
